@@ -6,7 +6,7 @@ use warnings;
 use Test::BDD::Cucumber::StepFile qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::HTTP qw(C :util);
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -67,16 +67,4 @@ Then qr/http response content must be like "(.+)"/, sub {
     content_re($value);
 };
 
-Then qr/http response decoded content must be "(.+)"/, sub {
-    my ($value) = ($1);
-
-    content_eq_decoded($value);
-};
-
-Then qr/http response decoded content must be like "(.+)"/, sub {
-    my ($value) = ($1);
-
-    content_re_decoded($value);
-};
-
 1;
